==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/lt_LT.js <==
OC.L10N.register(
    "settings",
    {
    "{actor} changed your password" : "{actor} pakeitė jūsų slaptažodį",
    "You changed your password" : "Jūs pakeitėte savo slaptažodį",
    "Your password was reset by an administrator" : "Administratorius atstatė jūsų slaptažodį",
    "{actor} changed your email address" : "{actor} pakeitė jūsų el. pašto adresą",
    "You changed your email address" : "Jūs pakeitėte savo el. pašto adresą",
    "Your email address was changed by an administrator" : "Administratorius pakeitė jūsų el. pašto adresą",
    "Security" : "Saugumas",
    "You successfully logged in using two-factor authentication (%1$s)" : "Jūs sėkmingai prisijungėte, naudodami dviejų faktorių tapatybės nustatymą (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Nepavyko prisijungti, naudojant dviejų faktorių tapatybės nustatymą (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Jūsų <strong>slaptažodis</strong> ar <strong>el. paštas</strong> buvo pakeisti",
    "Your apps" : "Jūsų programėlės",
    "Updates" : "Atnaujinimai",
    "Enabled apps" : "Įjungtos programėlės",
    "Disabled apps" : "Išjungtos programėlės",
    "App bundles" : "Programėlių rinkiniai",
    "Wrong password" : "Neteisingas slaptažodis",
    "Saved" : "Įrašyta",
    "No user supplied" : "Nepateiktas naudotojas",
    "Unable to change password" : "Nepavyksta pakeisti slaptažodžio",
    "Authentication error" : "Tapatybės nustatymo klaida",
    "Wrong admin recovery password. Please check the password and try again." : "Netinkamas administratoriaus atkūrimo slaptažodis. Prašome pasitikrinti ir bandyti vėl.",
    "A problem occurred, please check your log files (Error: %s)" : "Atsirado problema, prašome patikrinti savo žurnalo failus (Klaida: %s)",
    "Migration Completed" : "Perkėlimas baigtas",
    "Group already exists." : "Grupė jau yra.",
    "Unable to add group." : "Nepavyko pridėti grupės.",
    "Unable to delete group." : "Nepavyko ištrinti grupės.",
    "Invalid SMTP password." : "Neteisingas SMTP slaptažodis.",
    "Email setting test" : "El. pašto nustatymo testas",
    "Email could not be sent. Check your mail server log" : "El. laiškas nebuvo išsiųstas. Peržiūrėkite savo pašto serverio žurnalą.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Įvyko klaida išsiunčiant laišką. Prašome peržiūrėkite savo nustatymus. (Klaida: %s)",
    "You need to set your user email before being able to send test emails." : "Jūs turite nurodyti elektroninio pašto adresą, kad galėtumėte siųsti testinius el. laiškus.",
    "Invalid mail address" : "Neteisingas pašto adresas",
    "No valid group selected" : "Pasirinkta neteisinga grupė",
    "A user with that name already exists." : "Toks naudotojas jau yra.",
    "To send a password link to the user an email address is required." : "Norint persiųsti slaptažodžio nuorodą, būtinas el. pašto adresas.",
    "Unable to create user." : "Nepavyko sukurti naudotojo.",
    "Unable to delete user." : "Nepavyko ištrinti naudotojo.",
    "Error while enabling user." : "Klaida įjungiant naudotoją.",
    "Error while disabling user." : "Klaida išjungiant naudotoją.",
    "Settings saved" : "Nustatymai įrašyti",
    "Unable to change full name" : "Nepavyko pakeisti pilno vardo",
    "Unable to change email address" : "Nepavyko pakeisti el. pašto adresą",
    "Your full name has been changed." : "Pilnas vardas pakeistas.",
    "Forbidden" : "Uždrausta",
    "Invalid user" : "Neteisingas naudotojas",
    "Unable to change mail address" : "Nepavyko pakeisti el. pašto adresą",
    "Email saved" : "El. paštas įrašytas",
    "%1$s changed your password on %2$s." : "%1$s pakeitė jūsų slaptažodį %2$s",
    "The new email address is %s" : "Naujasis el. pašto adresas yra %s",
    "Your %s account was created" : "Jūsų paskyra %s sukurta",
    "Your username is: %s" : "Jūsų naudotojo vardas yra: %s",
    "Password confirmation is required" : "Reikalingas slaptažodžio patvirtinimas",
    "Couldn't remove app." : "Nepavyko pašalinti programėlės.",
    "Couldn't update app." : "Nepavyko atnaujinti programėlės.",
    "Add trusted domain" : "Pridėti patikimą domeną",
    "Migration in progress. Please wait until the migration is finished" : "Vyksta perkėlimas. Palaukite, kol perkėlimas bus užbaigtas",
    "Migration started …" : "Perkėlimas pradėtas …",
    "Not saved" : "Neįrašyta",
    "Sending…" : "Siunčiama…",
    "Email sent" : "El. paštas išsiųstas",
    "Official" : "Oficiali",
    "All" : "Viskas",
    "Update to %s" : "Atnaujinti į %s",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Oficialios programėlės yra kuriamos bendruomenės viduje ir jas kuria bendruomenė. Šios programėlės siūlo centrinį funkcionalumą ir yra paruoštos kasdieniam naudojimui.",
    "Disabling app …" : "Išjungiama programėlė …",
    "Error while disabling app" : "Klaida, išjungiant programėlę",
    "Disable" : "Išjungti",
    "Enable" : "Įjungti",
    "Enabling app …" : "Programėlė įjungiama",
    "Error while enabling app" : "Klaida, įjungiant programėlę",
    "Updated" : "Atnaujinta",
    "Removing …" : "Šalinama …",
    "Remove" : "Šalinti",
    "Approved" : "Patvirtinta",
    "Experimental" : "Eksperimentinė",
    "Disconnect" : "Atjungti",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome, skirta Android",
    "iPhone iOS" : "iPhone iOS",
    "iPad iOS" : "iPad iOS",
    "iOS Client" : "iOS klientas",
    "Android Client" : "Android klientas",
    "This session" : "Šis seansas",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Error while loading browser sessions and device tokens" : "Klaida, įkeliant naršyklės seansus ir įrenginio prieigos raktus",
    "Error while creating device token" : "Klaida, kuriant įrenginio prieigos raktą",
    "Error while deleting the token" : "Klaida, ištrinant prieigos raktą",
    "Valid until {date}" : "Galioja iki {date}",
    "Delete" : "Ištrinti",
    "Only visible to local users" : "Matoma tik vietiniams naudotojams",
    "Only visible to you" : "Matoma tik jums",
    "Visible to local users and to trusted servers" : "Matoma tik vietiniams naudotojams ir patikimiems serveriams",
    "Public" : "Viešai",
    "Select a profile picture" : "Pasirinkite profilio paveikslą",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "Groups" : "Grupės",
    "Error creating group: {message}" : "Klaida kuriant grupę: {message}",
    "undo" : "anuliuoti",
    "never" : "niekada",
    "Add group" : "Pridėti grupę",
    "Password successfully changed" : "Slaptažodis sėkmingai pakeistas",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Slaptažodžio pakeitimas sąlygos duomenų praradimą, kadangi šiam naudotojui nėra prieinamas duomenų atkūrimas",
    "A valid username must be provided" : "Privalo būti pateiktas tinkamas naudotojo vardas",
    "A valid password must be provided" : "Slaptažodis turi būti tinkamas",
    "Documentation:" : "Dokumentacija:",
    "User documentation" : "Naudotojo dokumentacija",
    "Admin documentation" : "Administratoriaus dokumentacija",
    "Report a bug" : "Pranešti apie klaidą",
    "Show description …" : "Rodyti aprašą …",
    "Hide description …" : "Slėpti aprašą …",
    "This app has an update available." : "Šiai programėlei yra prieinamas atnaujinimas.",
    "Online documentation" : "Dokumentacija internete",
    "Forum" : "Forumas",
    "None" : "Nieko",
    "Login" : "Prisijungti",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "El. pašto serveris",
    "Open documentation" : "Atverti dokumentaciją",
    "Encryption" : "Šifravimas",
    "Authentication required" : "Reikalingas tapatybės nustatymas",
    "Server address" : "Serverio adresas",
    "Port" : "Prievadas",
    "SMTP Username" : "SMTP naudotojo vardas",
    "SMTP Password" : "SMTP slaptažodis",
    "Server-side encryption" : "Šifravimas serveryje",
    "Be aware that encryption always increases the file size." : "Turėkite omenyje, kad šifravimas visada padidina failų dydį.",
    "This is the final warning: Do you really want to enable encryption?" : "Tai yra paskutinis įspėjimas: Ar tikrai norite įjungti šifravimą?",
    "Enable encryption" : "Įjungti šifravimą",
    "Select default encryption module:" : "Pasirinkite numatytąjį šifravimo modulį:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Jūs turite perkelti savo šifravimo raktus iš senojo šifravimo (ownCloud <= 8.0) į naująjį. Prašome įjungti \"Numatytąjį šifravimo modulį\" ir įvykdyti \"occ encryption:migrate\"",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Jūs turite perkelti savo šifravimo raktus iš senojo šifravimo (ownCloud <= 8.0) į naująjį.",
    "Start migration" : "Pradėti perkėlimą",
    "Security & setup warnings" : "Saugos ir diegimo perspėjimai",
    "Execute one task with each page loaded" : "Įvykdyti vieną užduotį su kiekvieno puslapio įkėlimu",
    "Version" : "Versija",
    "Sharing" : "Dalijimasis",
    "Allow apps to use the Share API" : "Leidžia programoms naudoti Share API",
    "Allow public uploads" : "Leisti viešus įkėlimus",
    "days" : "dienos",
    "Allow resharing" : "Leisti dalintis",
    "Tips & tricks" : "Patarimai ir gudrybės",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation ↗</a>." : "Norėdami persikelti į kitą duomenų bazę, naudokite komandų eilutės įrankį: \"occ db:convert-type\" arba žiūrėkite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaciją ↗</a>.",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Jūs naudojate <strong>%s</strong> iš <strong>%s</strong>",
    "Profile picture" : "Profilio paveikslas",
    "Upload new" : "Įkelti naują",
    "Remove image" : "Šalinti paveikslą",
    "png or jpg, max. 20 MB" : "png arba jpg, daugiausiai 20 MB",
    "Cancel" : "Atsisakyti",
    "Email" : "El. Paštas",
    "Your email address" : "Jūsų el. pašto adresas",
    "No email address set" : "Nenustatytas joks el. pašto adresas",
    "Phone number" : "Telefono numeris",
    "Your phone number" : "Jūsų telefono numeris",
    "Address" : "Adresas",
    "Website" : "Svetainė",
    "Twitter" : "Twitter",
    "You are member of the following groups:" : "Jūs esate šių grupių narys:",
    "Language" : "Kalba",
    "Help translate" : "Padėkite išversti",
    "Password" : "Slaptažodis",
    "Current password" : "Dabartinis slaptažodis",
    "New password" : "Naujas slaptažodis",
    "Change password" : "Pakeisti slaptažodį",
    "Web, desktop and mobile clients currently logged in to your account." : "Saityno, darbalaukio ir mobilieji klientai, kurie šiuo metu yra prisijungę prie jūsų paskyros.",
    "Device" : "Įrenginys",
    "Last activity" : "Paskutinė veikla",
    "App name" : "Programėlės pavadinimas",
    "Create new app password" : "Sukurti naują programėlės slaptažodį",
    "For security reasons this password will only be shown once." : "Saugumo sumetimais šis slaptažodis bus parodytas tik vieną kartą.",
    "Username" : "Naudotojo vardas",
    "Done" : "Atlikta",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Sukurta {communityopen}Nextcloud bendruomenės{linkclose}, {githubopen}pirminis kodas{linkclose} yra licencijuotas pagal {licenseopen}AGPL{linkclose}.",
    "Settings" : "Nustatymai",
    "Create" : "Sukurti",
    "Admin Recovery Password" : "Administracinis atkūrimo slaptažodis",
    "Enter the recovery password in order to recover the users files during password change" : "Įveskite atkūrimo slaptažodį, kad atkurtumėte naudotojo failus keičiant slaptažodį",
    "Unlimited" : "Neribotai",
    "Other" : "Kita",
    "Quota" : "Limitas",
    "change full name" : "keisti pilną vardą",
    "set new password" : "nustatyti naują slaptažodį",
    "Default" : "Numatytasis",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Norėdami persikelti į kitą duomenų bazę, naudokite komandų eilutės įrankį: \"occ db:convert-type\" arba žiūrėkite <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentaciją ↗</a>."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/lt_LT.js <==
OC.L10N.register(
    "settings",
    {
    "{actor} changed your password" : "{actor} pakeitė jūsų slaptažodį",
    "You changed your password" : "Jūs pakeitėte savo slaptažodį",
    "Your password was reset by an administrator" : "Administratorius atstatė jūsų slaptažodį",
    "{actor} changed your email address" : "{actor} pakeitė jūsų el. pašto adresą",
    "You changed your email address" : "Jūs pakeitėte savo el. pašto adresą",
    "Your email address was changed by an administrator" : "Administratorius pakeitė jūsų el. pašto adresą",
    "Security" : "Saugumas",
    "You successfully logged in using two-factor authentication (%1$s)" : "Jūs sėkmingai prisijungėte, naudodami dviejų faktorių tapatybės nustatymą (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Nepavyko prisijungti, naudojant dviejų faktorių tapatybės nustatymą (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Jūsų <strong>slaptažodis</strong> ar <strong>el. paštas</strong> buvo pakeisti",
    "Your apps" : "Jūsų programėlės",
    "Updates" : "Atnaujinimai",
    "Enabled apps" : "Įjungtos programėlės",
    "Disabled apps" : "Išjungtos programėlės",
    "App bundles" : "Programėlių rinkiniai",
    "Wrong password" : "Neteisingas slaptažodis",
    "Saved" : "Įrašyta",
    "No user supplied" : "Nepateiktas naudotojas",
    "Unable to change password" : "Nepavyksta pakeisti slaptažodžio",
    "Authentication error" : "Tapatybės nustatymo klaida",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Pateikite administratoriaus atkūrimo slaptažodį; kitu atveju visi naudotojo duomenis bus prarasti.",
    "Wrong admin recovery password. Please check the password and try again." : "Netinkamas administratoriaus atkūrimo slaptažodis. Prašome pasitikrinti ir bandyti vėl.",
    "Group already exists." : "Grupė jau yra.",
    "Unable to add group." : "Nepavyko pridėti grupės.",
    "Unable to delete group." : "Nepavyko ištrinti grupės.",
    "Invalid SMTP password." : "Neteisingas SMTP slaptažodis.",
    "Email setting test" : "El. pašto nustatymo testas",
    "Email could not be sent. Check your mail server log" : "El. laiškas nebuvo išsiųstas. Peržiūrėkite savo pašto serverio žurnalą.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Įvyko klaida išsiunčiant laišką. Prašome peržiūrėkite savo nustatymus. (Klaida: %s)",
    "You need to set your user email before being able to send test emails." : "Jūs turite nurodyti elektroninio pašto adresą, kad galėtumėte siųsti testinius el. laiškus.",
    "Invalid mail address" : "Neteisingas pašto adresas",
    "No valid group selected" : "Pasirinkta neteisinga grupė",
    "A user with that name already exists." : "Toks naudotojas jau yra.",
    "To send a password link to the user an email address is required." : "Norint persiųsti slaptažodžio nuorodą, būtinas el. pašto adresas.",
    "Unable to create user." : "Nepavyko sukurti naudotojo.",
    "Unable to delete user." : "Nepavyko ištrinti naudotojo.",
    "Error while enabling user." : "Klaida įjungiant naudotoją.",
    "Error while disabling user." : "Klaida išjungiant naudotoją.",
    "Settings saved" : "Nustatymai įrašyti",
    "Unable to change full name" : "Nepavyko pakeisti pilno vardo",
    "Unable to change email address" : "Nepavyko pakeisti el. pašto adresą",
    "Your full name has been changed." : "Pilnas vardas pakeistas.",
    "Forbidden" : "Uždrausta",
    "Invalid user" : "Neteisingas naudotojas",
    "Unable to change mail address" : "Nepavyko pakeisti el. pašto adresą",
    "Email saved" : "El. paštas įrašytas",
    "%1$s changed your password on %2$s." : "%1$s pakeitė jūsų slaptažodį %2$s",
    "The new email address is %s" : "Naujasis el. pašto adresas yra %s",
    "Your %s account was created" : "Jūsų paskyra %s sukurta",
    "Your username is: %s" : "Jūsų naudotojo vardas yra: %s",
    "Password confirmation is required" : "Reikalingas slaptažodžio patvirtinimas",
    "Couldn't remove app." : "Nepavyko pašalinti programėlės.",
    "Couldn't update app." : "Nepavyko atnaujinti programėlės.",
    "Migration in progress. Please wait until the migration is finished" : "Vyksta perkėlimas. Palaukite, kol perkėlimas bus užbaigtas",
    "Migration started …" : "Perkėlimas pradėtas …",
    "Not saved" : "Neįrašyta",
    "Sending…" : "Siunčiama…",
    "Email sent" : "El. paštas išsiųstas",
    "Official" : "Oficiali",
    "All" : "Viskas",
    "Update to %s" : "Atnaujinti į %s",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Oficialios programėlės yra kuriamos bendruomenės viduje ir jas kuria bendruomenė. Šios programėlės siūlo centrinį funkcionalumą ir yra paruoštos kasdieniam naudojimui.",
    "Disabling app …" : "Išjungiama programėlė …",
    "Error while disabling app" : "Klaida, išjungiant programėlę",
    "Disable" : "Išjungti",
    "Enable" : "Įjungti",
    "Enabling app …" : "Programėlė įjungiama",
    "Error while enabling app" : "Klaida, įjungiant programėlę",
    "Updated" : "Atnaujinta",
    "Removing …" : "Šalinama …",
    "Remove" : "Šalinti",
    "Approved" : "Patvirtinta",
    "Experimental" : "Eksperimentinė",
    "Disconnect" : "Atjungti",
    "Revoke" : "Panaikinti",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome, skirta Android",
    "iPhone iOS" : "iPhone iOS",
    "iPad iOS" : "iPad iOS",
    "iOS Client" : "iOS klientas",
    "Android Client" : "Android klientas",
    "This session" : "Šis seansas",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Error while loading browser sessions and device tokens" : "Klaida, įkeliant naršyklės seansus ir įrenginio prieigos raktus",
    "Error while creating device token" : "Klaida, kuriant įrenginio prieigos raktą",
    "Error while deleting the token" : "Klaida, ištrinant prieigos raktą",
    "Valid until {date}" : "Galioja iki {date}",
    "Delete" : "Ištrinti",
    "Only visible to local users" : "Matoma tik vietiniams naudotojams",
    "Only visible to you" : "Matoma tik jums",
    "Visible to local users and to trusted servers" : "Matoma tik vietiniams naudotojams ir patikimiems serveriams",
    "Public" : "Viešai",
    "Select a profile picture" : "Pasirinkite profilio paveikslą",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "Groups" : "Grupės",
    "Error creating group: {message}" : "Klaida kuriant grupę: {message}",
    "undo" : "anuliuoti",
    "never" : "niekada",
    "Add group" : "Pridėti grupę",
    "Invalid quota value \"{val}\"" : "Neteisinga leidžiamo duomenų kiekio reikšmė \"{val}\"",
    "Password successfully changed" : "Slaptažodis sėkmingai pakeistas",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Slaptažodžio pakeitimas sąlygos duomenų praradimą, kadangi šiam naudotojui nėra prieinamas duomenų atkūrimas",
    "A valid username must be provided" : "Privalo būti pateiktas tinkamas naudotojo vardas",
    "Error creating user: {message}" : "Klaida kuriant naudotoją: {message}",
    "Documentation:" : "Dokumentacija:",
    "User documentation" : "Naudotojo dokumentacija",
    "Admin documentation" : "Administratoriaus dokumentacija",
    "Report a bug" : "Pranešti apie klaidą",
    "Show description …" : "Rodyti aprašą …",
    "Hide description …" : "Slėpti aprašą …",
    "This app has an update available." : "Šiai programėlei yra prieinamas atnaujinimas.",
    "Online documentation" : "Dokumentacija internete",
    "Forum" : "Forumas",
    "None" : "Nieko",
    "Login" : "Prisijungti",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "El. pašto serveris",
    "Open documentation" : "Atverti dokumentaciją",
    "Encryption" : "Šifravimas",
    "Authentication required" : "Reikalingas tapatybės nustatymas",
    "Server address" : "Serverio adresas",
    "Port" : "Prievadas",
    "SMTP Username" : "SMTP naudotojo vardas",
    "SMTP Password" : "SMTP slaptažodis",
    "Server-side encryption" : "Šifravimas serveryje",
    "Be aware that encryption always increases the file size." : "Turėkite omenyje, kad šifravimas visada padidina failų dydį.",
    "This is the final warning: Do you really want to enable encryption?" : "Tai yra paskutinis įspėjimas: Ar tikrai norite įjungti šifravimą?",
    "Enable encryption" : "Įjungti šifravimą",
    "Select default encryption module:" : "Pasirinkite numatytąjį šifravimo modulį:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Jūs turite perkelti savo šifravimo raktus iš senojo šifravimo (ownCloud <= 8.0) į naująjį. Prašome įjungti \"Numatytąjį šifravimo modulį\" ir įvykdyti \"occ encryption:migrate\"",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Jūs turite perkelti savo šifravimo raktus iš senojo šifravimo (ownCloud <= 8.0) į naująjį.",
    "Start migration" : "Pradėti perkėlimą",
    "Security & setup warnings" : "Saugos ir diegimo perspėjimai",
    "Background jobs" : "Foninės užduotys",
    "Last job ran %s." : "Paskutinė užduotis buvo vykdyta %s.",
    "Last job execution ran %s. Something seems wrong." : "Paskutinės užduoties vykdymas vyko %s. Atrodo, kad kažkas nutiko.",
    "Background job didn’t run yet!" : "Foninės užduotys kol kas nebuvo vykdomos!",
    "Execute one task with each page loaded" : "Įvykdyti vieną užduotį su kiekvieno puslapio įkėlimu",
    "Version" : "Versija",
    "Sharing" : "Dalijimasis",
    "Allow apps to use the Share API" : "Leidžia programoms naudoti Share API",
    "Allow public uploads" : "Leisti viešus įkėlimus",
    "days" : "dienos",
    "Allow resharing" : "Leisti dalintis",
    "Tips & tricks" : "Patarimai ir gudrybės",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation ↗</a>." : "Norėdami persikelti į kitą duomenų bazę, naudokite komandų eilutės įrankį: \"occ db:convert-type\" arba žiūrėkite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaciją ↗</a>.",
    "How to do backups" : "Kaip daryti atsargines kopijas",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Jūs naudojate <strong>%s</strong> iš <strong>%s</strong>",
    "Profile picture" : "Profilio paveikslas",
    "Upload new" : "Įkelti naują",
    "Remove image" : "Šalinti paveikslą",
    "png or jpg, max. 20 MB" : "png arba jpg, daugiausiai 20 MB",
    "Cancel" : "Atsisakyti",
    "You are member of the following groups:" : "Jūs esate šių grupių narys:",
    "Email" : "El. Paštas",
    "Your email address" : "Jūsų el. pašto adresas",
    "No email address set" : "Nenustatytas joks el. pašto adresas",
    "Phone number" : "Telefono numeris",
    "Your phone number" : "Jūsų telefono numeris",
    "Address" : "Adresas",
    "Website" : "Svetainė",
    "Twitter" : "Twitter",
    "Language" : "Kalba",
    "Help translate" : "Padėkite išversti",
    "Password" : "Slaptažodis",
    "Current password" : "Dabartinis slaptažodis",
    "New password" : "Naujas slaptažodis",
    "Change password" : "Pakeisti slaptažodį",
    "Web, desktop and mobile clients currently logged in to your account." : "Saityno, darbalaukio ir mobilieji klientai, kurie šiuo metu yra prisijungę prie jūsų paskyros.",
    "Device" : "Įrenginys",
    "Last activity" : "Paskutinė veikla",
    "App name" : "Programėlės pavadinimas",
    "Create new app password" : "Sukurti naują programėlės slaptažodį",
    "For security reasons this password will only be shown once." : "Saugumo sumetimais šis slaptažodis bus parodytas tik vieną kartą.",
    "Username" : "Naudotojo vardas",
    "Done" : "Atlikta",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Sukurta {communityopen}Nextcloud bendruomenės{linkclose}, {githubopen}pirminis kodas{linkclose} yra licencijuotas pagal {licenseopen}AGPL{linkclose}.",
    "Settings" : "Nustatymai",
    "Show last login" : "Rodyti paskutinį prisijungimą",
    "Disabled" : "Išjungta",
    "Default quota" : "Numatytasis leidžiamas duomenų kiekis",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Įveskite saugyklos leidžiamą duomenų kiekį (pvz.: \"512 MB\" ar \"12 GB\")",
    "Unlimited" : "Neribotai",
    "Other" : "Kita",
    "Quota" : "Limitas",
    "Admin Recovery Password" : "Administracinis atkūrimo slaptažodis",
    "Enter the recovery password in order to recover the users files during password change" : "Įveskite atkūrimo slaptažodį, kad atkurtumėte naudotojo failus keičiant slaptažodį",
    "change full name" : "keisti pilną vardą",
    "set new password" : "nustatyti naują slaptažodį",
    "Default" : "Numatytasis",
    "A problem occurred, please check your log files (Error: %s)" : "Atsirado problema, prašome patikrinti savo žurnalo failus (Klaida: %s)",
    "Migration Completed" : "Perkėlimas baigtas",
    "Add trusted domain" : "Pridėti patikimą domeną",
    "Updating...." : "Atnaujinama...",
    "A valid password must be provided" : "Slaptažodis turi būti tinkamas",
    "__language_name__" : "Lietuvių",
    "Personal info" : "Asmeninė informacija",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Norėdami persikelti į kitą duomenų bazę, naudokite komandų eilutės įrankį: \"occ db:convert-type\" arba žiūrėkite <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentaciją ↗</a>.",
    "Show First Run Wizard again" : "Dar kartą rodyti pirmojo paleidimo vediklį",
    "Follow us on Google+!" : "Sekite mus Google+!",
    "Follow us on Twitter!" : "Sekite mus Twitter!",
    "Subscribe to our newsletter!" : "Prenumeruokite mūsų naujienlaiškį!",
    "Show email address" : "Rodyti el. pašto adresą",
    "Create" : "Sukurti"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
